==> aliyun-sdk-oss-2.7.0-sources.jar: com/aliyun/oss/model/ListBucketsRequest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package com.aliyun.oss.model;

import com.aliyun.oss.internal.OSSUtils;

public class ListBucketsRequest extends WebServiceRequest {
    
    public static final int MAX_RETURNED_KEYS = 1000;
    
    // prefix限定返回的object key必须以prefix作为前缀。
    private String prefix;
    
    // maker用户设定结果从marker之后按字母排序的第一个开始返回。
    private String marker;

    // 用于限定此次返回bucket的最大数，如果不设定，默认为100。
    private Integer maxKeys;
    
    // OSS的BID为26842
    private String bid;
    
    /**
     * 构造函数。
     */
    public ListBucketsRequest() { }

    /**
     * 构造函数。
     * @param prefix
     *          prefix限定返回的bucket name必须以prefix作为前缀。
     * @param marker
     *          maker用户设定结果从marker之后按字母排序的第一个开始返回。
     * @param maxKeys
     *          用于限定此次返回object的最大数，如果不设定，默认为100。
     */
    public ListBucketsRequest(String prefix, String marker, Integer maxKeys) {
        setPrefix(prefix);
        setMarker(marker);
        if (maxKeys != null) {
            setMaxKeys(maxKeys);
        }
    }

    /**
     * 返回prefix，限定返回的bucket name必须以prefix作为前缀。
     * @return
     *      prefix
     */
    public String getPrefix() {
        return prefix;
    }

    /**
     * 设置prefix，限定返回的bucket name必须以prefix作为前缀。
     * @param prefix
     *          前缀prefix。
     */
    public void setPrefix(String prefix) {
        this.prefix = prefix;
    }
    
    /**
     * 设置prefix，限定返回的bucket name必须以prefix作为前缀。
     * @param prefix
     *          前缀prefix。
     */
    public ListBucketsRequest withPrefix(String prefix) {
        setPrefix(prefix);
        return this;
    }

    /**
     * 返回marker，用户设定结果从marker之后按字母排序的第一个开始返回。
     * @return
     *          marker
     */
    public String getMarker() {
        return marker;
    }

    /**
     * 设置marker, 用户设定结果从marker之后按字母排序的第一个开始返回。
     * @param marker
     *          marker
     */
    public void setMarker(String marker) {
        this.marker = marker;
    }
    
    /**
     * 设置marker, 用户设定结果从marker之后按字母排序的第一个开始返回。
     * @param marker
     *          marker
     */
    public ListBucketsRequest withMarker(String marker) {
        setMarker(marker);
        return this;
    }

    /**
     * 返回用于限定此次返回bucket的最大数，如果不设定，默认为100。
     * @return
     *      用于限定此次返回bucket的最大数。
     */
    public Integer getMaxKeys() {
        return maxKeys;
    }

    /**
     * 设置用于限定此次返回bucket的最大数，如果不设定，默认为100。最大值为1000。
     * @param maxKeys
     *      用于限定此次返回bucket的最大数。最大值为1000。
     */
    public void setMaxKeys(Integer maxKeys) {
        int tmp = maxKeys.intValue();
        if (tmp < 0 || tmp > MAX_RETURNED_KEYS) {
            throw new IllegalArgumentException(
                OSSUtils.OSS_RESOURCE_MANAGER.getString("MaxKeysOutOfRange"));
        }
        this.maxKeys = maxKeys;
    }
    
    /**
     * 设置用于限定此次返回bucket的最大数，如果不设定，默认为100。最大值为1000。
     * @param maxKeys
     *      用于限定此次返回bucket的最大数。最大值为1000。
     */
    public ListBucketsRequest withMaxKeys(Integer maxKeys) {
        setMaxKeys(maxKeys);
        return this;
    }
    
    /**
     * 设置bid。
     * @param bid bid。
     */
    public void setBid(String bid) {
        this.bid = bid;
    }
    
    /**
     * 返回用于bid。
     * @return bid。
     * 
     */
    public String getBid() {
        return bid;
    }
}

==> aliyun-sdk-oss-2.8.3-sources.jar: com/aliyun/oss/model/ListBucketsRequest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package com.aliyun.oss.model;

import com.aliyun.oss.internal.OSSUtils;

public class ListBucketsRequest extends WebServiceRequest {
    
    public static final int MAX_RETURNED_KEYS = 1000;
    
    // The prefix filter for the buckets to return. In the other words, all buckets returned must start with this prefix.
    private String prefix;
    
    // The maker filter for the buckets to return. In the other words, all buckets returned must be greater than the marker
    // in the lexicographical order.
    private String marker;

    // The max number of buckets to return.By default it's 100.
    private Integer maxKeys;

    // The OSS's Bid is 26842.
    private String bid;
    
    /**
     * Constructor.
     */
    public ListBucketsRequest() { }

    /**
     * Constructor.
     * @param prefix
     *          Prefix filter, all buckets returned must start with this prefix.
     * @param marker
     *          Maker filter, all buckets returned must be greater than the marker.
     * @param maxKeys
     *          Max number of buckets to return, by default is 100,
     */
    public ListBucketsRequest(String prefix, String marker, Integer maxKeys) {
        setPrefix(prefix);
        setMarker(marker);
        if (maxKeys != null) {
            setMaxKeys(maxKeys);
        }
    }

    /**
     * Gets the prefix filter.
     * @return
     *      The prefix filter.
     */
    public String getPrefix() {
        return prefix;
    }

    /**
     * Sets the prefix filter.
     * @param prefix
     *          The prefix filter.
     */
    public void setPrefix(String prefix) {
        this.prefix = prefix;
    }
    
    /**
     * Sets the prefix filter and return the current ListBucketsRequest instance (this).
     * @param prefix
     *          The prefix filter.
     */
    public ListBucketsRequest withPrefix(String prefix) {
        setPrefix(prefix);
        return this;
    }

    /**
     * Gets the marker filter.
     * @return
     *         The marker filter.
     */
    public String getMarker() {
        return marker;
    }

    /**
     * Sets the marker filter.
     * @param marker
     *          The marker filter.
     */
    public void setMarker(String marker) {
        this.marker = marker;
    }
    
    /**
     * Sets the marker filter and return the current ListBucketRequest instance (this).
     * @param marker
     *          The marker filter.
     */
    public ListBucketsRequest withMarker(String marker) {
        setMarker(marker);
        return this;
    }

    /**
     * Gets the max number of buckets to return. By default it's 100.
     * @return
     *      The max number of buckets.
     */
    public Integer getMaxKeys() {
        return maxKeys;
    }

    /**
     * Sets the max number of buckets to return. By default it's 100, the max is 1000.
     * @param maxKeys
     *      The max number of buckets.
     */
    public void setMaxKeys(Integer maxKeys) {
        int tmp = maxKeys.intValue();
        if (tmp < 0 || tmp > MAX_RETURNED_KEYS) {
            throw new IllegalArgumentException(
                OSSUtils.OSS_RESOURCE_MANAGER.getString("MaxKeysOutOfRange"));
        }
        this.maxKeys = maxKeys;
    }
    
    /**
     * Sets the max number of buckets to return the current ListBucketsRequest instance (this).
     * @param maxKeys
     *      The max number of buckets.
     */
    public ListBucketsRequest withMaxKeys(Integer maxKeys) {
        setMaxKeys(maxKeys);
        return this;
    }
    
    /**
     * Sets the bid。
     * @param bid bid。
     */
    public void setBid(String bid) {
        this.bid = bid;
    }
    
    /**
     * Gets the bid.
     * @return bid。
     * 
     */
    public String getBid() {
        return bid;
    }
}
